'use strict';
import { retrieveCommitMessages } from './retrieveCommitMessages.js';
import { validateClassPaths } from './validateClassPaths.js';
export async function extractTestClasses(fromRef, toRef, regex) {
    const testClasses = new Set();
    const matchedMessages = await retrieveCommitMessages(fromRef, toRef, regex);
    matchedMessages.forEach((message) => {
        // Split the commit message by commas or spaces
        const classes = message.split(/,|\s/);
        classes.forEach((testClass) => {
            // Remove leading/trailing whitespaces and add non-empty strings to the set
            const trimmedClass = testClass.trim();
            if (trimmedClass !== '') {
                testClasses.add(trimmedClass);
            }
        });
    });
    const unvalidatedClasses = Array.from(testClasses);
    let validatedClasses = '';
    const result = unvalidatedClasses.length > 0
        ? await validateClassPaths(unvalidatedClasses, toRef)
        : { validatedClasses: new Set(), warnings: [] };
    let sortedClasses = [];
    if (result.validatedClasses.size > 0) {
        sortedClasses = Array.from(result.validatedClasses);
        sortedClasses = sortedClasses.sort((a, b) => a.localeCompare(b));
        validatedClasses = sortedClasses.join(' ');
    }
    return { validatedClasses, warnings: result.warnings };
}
//# sourceMappingURL=extractTestClasses.js.map