'use strict';
import { readFileSync } from 'node:fs';
import { simpleGit } from 'simple-git';
export async function retrieveCommitMessages(fromCommit, toCommit, regexFilePath) {
    const options = {
        baseDir: process.cwd(),
        binary: 'git',
        maxConcurrentProcesses: 6,
        trimmed: true,
    };
    const git = simpleGit(options);
    const result = await git.log({ from: fromCommit, to: toCommit, format: '%s' });
    // Filter only entries that match the DefaultLogFields type
    const commitMessages = result.all.map((commit) => commit.message);
    let regex;
    let regexPattern = '';
    try {
        regexPattern = readFileSync(regexFilePath, 'utf-8').trim();
        regex = new RegExp(regexPattern, 'g');
    }
    catch (err) {
        throw Error(`The regular expression in '${regexFilePath}' is invalid.`);
    }
    const matchedMessages = [];
    commitMessages.forEach((message) => {
        let match;
        while ((match = regex.exec(message)) !== null) {
            if (match[1]) {
                matchedMessages.push(match[1]);
            }
        }
    });
    return matchedMessages;
}
//# sourceMappingURL=retrieveCommitMessages.js.map